#
# spec file for package prozgui
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           prozgui
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
Summary:        GUI Advanced Linux Download Manager
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Utilities
Version:        2.0.5beta
Release:        lp150.2.1
Url:            http://prozilla.genesys.ro
Source0:        http://prozilla.genesys.ro/downloads/prozgui/tarballs/prozgui-2.0.5beta.tar.bz2
Source1:        COPYING
Patch0:         prozgui-2.0.5beta-autoconf.diff
Patch1:         prozgui-2.0.5beta-gettext.diff
Patch2:         prozgui-2.0.5beta-strcpy.diff
Patch3:         prozgui-2.0.5beta-include.diff
Patch4:         prozgui-2.0.5beta-oldmacros.diff
Patch5:         prozgui-retval.diff
Patch6:         prozgui-gcc4.diff
Patch7:         prozgui-2.0.5beta-qualification.diff
Patch8:         prozgui-2.0.5beta-locale.diff
Patch9:         prozgui-2.0.5beta_remove-redefinitions.patch
Patch10:        prozgui-fltk13.diff
Patch11:        prozgui-2.0.5beta-automake-1.13.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is the GUI version of ProZilla. It uses libprozilla and the GUI is
created and designed with the Fast Light Tool Kit (fltk).

ProZilla is a download accelerator program written for Linux to speed
up the normal file download process. It often gives speed increases of
around 200% to 300%. It supports both the FTP and HTTP protocols, and
the theory behind it is very simple. The program opens multiple
connections to a server, and each of the connections downloads a part
of the file, thus defeating existing Internet congestion prevention
methods which slow down a single connection based download.

%prep
%setup
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%patch9
%patch10 -p1
%patch11 -p1
rm INSTALL

%build
export CFLAGS="$RPM_OPT_FLAGS" 
export CXXFLAGS="$RPM_OPT_FLAGS"
gettextize -f --no-changelog
gettextize -f --no-changelog libprozilla
autoreconf -fi
test -f po/Makevars || cp po/Makevars.template po/Makevars
test -f libprozilla/po/Makevars || cp libprozilla/po/Makevars.template libprozilla/po/Makevars
# changed the prefix to /usr due to new X.org doesnt use X11R6 dir anymore 
# fltk should be checked in at the same time
# FLTK_PREFIX=/usr/X11R6
FLTK_PREFIX=/usr
CFLAGS="$RPM_OPT_FLAGS" \
CXXFLAGS="$RPM_OPT_FLAGS" \
%configure \
	--with-fltk-libs="$FLTK_PREFIX/%{_lib}" \
	--with-fltk-includes="$FLTK_PREFIX/include" \
	--enable-shared \
	--disable-static \
	--with-pic
# C[XX]FLAGS must be used this way. For some unknown reasons it is not enough
# to just export them
make \
CFLAGS="-Wall -ggdb -D_REENTRANT $RPM_OPT_FLAGS" \
CXXFLAGS="-I$FLTK_PREFIX/include $RPM_OPT_FLAGS"

%install
make DESTDIR=%{buildroot} install
install -D -m 644 src/images/Pz12.xpm %{buildroot}%{_datadir}/pixmaps/prozgui.xpm
install -d -m 755 %{buildroot}%{_includedir}/prozilla
mv %{buildroot}%{_includedir}/*.h %{buildroot}%{_includedir}/prozilla/
%find_lang %{name}
%find_lang libprozilla %{name}.lang  

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr (-,root,root)
%doc COPYING ChangeLog CREDITS* README TODO docs/FAQ libprozilla/docs/HACKING
%{_bindir}/prozgui
%{_includedir}/prozilla
%{_libdir}/libprozilla*
%{_datadir}/pixmaps/*
%{_mandir}/man1/prozgui*

%changelog
* Thu Mar  1 2018 crrodriguez@opensuse.org
- Remove xorg-x11-devel buildrequires
* Tue Mar  5 2013 pgajdos@suse.com
- builds with automake 1.13
  * automake-1.13.patch
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jul 12 2011 pgajdos@novell.com
- build against fltk 1.3
* Mon Apr  4 2011 coolo@novell.com
- do not generate changelog entries for gettexize calls
- provide COPYING and not symlink it
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang problems
* Tue Nov 13 2007 pgajdos@suse.cz
- minor specfile change
* Tue Oct 16 2007 pgajdos@suse.cz
- removed redefinitions
  * remove-redefinitions.patch
- removed generic INSTALL instructions
- COPYING is now symlink to /usr/share/doc/licenses/md5
* Fri Mar 23 2007 lmichnovic@suse.cz
- forcing using CFLAGS and CXXFLAGS
* Mon Aug  7 2006 lmichnovic@suse.cz
- fixed implicit declaration of fuction setlocale (locale.diff)
- changed FLTK prefix to /usr due to changes in paths
- using gettextize -f to fix not expanding macro MKINSTALLDIRS
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 20 2005 lmichnovic@suse.cz
- fixed invalid extra qualification for build with new gcc 4.1
- glibc-devel was missing in dependency chain, added into needforbuild
* Mon May 16 2005 schwab@suse.de
- Undo last change.
- Remove AC_LANG_CPLUSPLUS.
- Fix build with gcc4.
* Mon Aug 30 2004 schwab@suse.de
- Move AC_PROG_LIBTOOL before AM_ENABLE_STATIC/AM_DISABLE_SHARED.
* Mon Jul 26 2004 schwab@suse.de
- Use autoreconf.
* Thu Apr 29 2004 ro@suse.de
- added return value in download.c (unreached code)
* Thu Jan 29 2004 ro@suse.de
- hardcode fltk-prefix in specfile
- remove outdated macros from acinclude.m4
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Aug 12 2003 ro@suse.de
- remove outdated aclocal.m4 files
* Wed Jun 11 2003 ro@suse.de
- libtoolize properly to get correct soname
* Wed May 28 2003 mjancar@suse.cz
- package headers in /usr/include/prozilla
* Wed May 14 2003 mjancar@suse.cz
- added missing include
* Tue Apr 15 2003 mjancar@suse.cz
- initial version for 2.0.5beta
- autoconf and gettext fixes
- fixed order of strcpy arguments
